@@ -1,12 +1,9 @@
 package MooseX::MethodAttributes::Inheritable;
-our $VERSION = '0.16_01';
+our $VERSION = '0.02';
 
 # ABSTRACT: inheritable code attribute introspection
 
 
-# Ensure trait is registered
-use MooseX::MethodAttributes::Role::Meta::Role ();
-
 use Moose;
 
 use namespace::clean -except => 'meta';
@@ -15,18 +12,16 @@ with 'MooseX::MethodAttributes::Role::AttrContainer::Inheritable';
 
 __PACKAGE__->meta->make_immutable;
 
+1;
 
 __END__
-
-=pod
-
 =head1 NAME
 
 MooseX::MethodAttributes::Inheritable - inheritable code attribute introspection
 
 =head1 VERSION
 
-version 0.16_01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -34,7 +29,7 @@ version 0.16_01
     use base qw/MooseX::MethodAttributes::Inheritable/;
 
     package SubClass;
-    use base qw/BaseClass/;
+    use base qw/SubClass/;
 
     sub foo : Bar {}
 
@@ -46,20 +41,14 @@ This module does the same as C<MooseX::MethodAttributes>, except that classes
 inheriting from other classes using it don't need to do anything special to get
 their code attributes captured.
 
-
-
-=head1 AUTHORS
+=head1 AUTHOR
 
   Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
+the same terms as perl itself.
 
