@@ -1,36 +1,39 @@
 package MooseX::MethodAttributes::Role::AttrContainer::Inheritable;
-our $VERSION = '0.16_01';
+our $VERSION = '0.02';
 
 # ABSTRACT: capture code attributes in the automatically initialized metaclass instance
 
 
 use Moose::Role;
-use MooseX::MethodAttributes ();
+use Moose::Util::MetaRole;
+use Moose::Util qw/find_meta does_role/;
 
 use namespace::clean -except => 'meta';
 
 with 'MooseX::MethodAttributes::Role::AttrContainer';
 
 before MODIFY_CODE_ATTRIBUTES => sub {
-    my ($class, $code, @attrs) = @_;
-    return unless @attrs;
-	MooseX::MethodAttributes->init_meta( for_class => $class );
+    my ($class) = @_;
+    my $meta = find_meta($class);
+    return if $meta && does_role($meta, 'MooseX::MethodAttributes::Role::Meta::Class');
+    Moose::Util::MetaRole::apply_metaclass_roles(
+        for_class                      => $class,
+        metaclass_roles                => ['MooseX::MethodAttributes::Role::Meta::Class'],
+        method_metaclass_roles         => ['MooseX::MethodAttributes::Role::Meta::Method'],
+        wrapped_method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
+    );
 };
 
 1;
 
-
 __END__
-
-=pod
-
 =head1 NAME
 
 MooseX::MethodAttributes::Role::AttrContainer::Inheritable - capture code attributes in the automatically initialized metaclass instance
 
 =head1 VERSION
 
-version 0.16_01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -38,20 +41,14 @@ This role extends C<MooseX::MethodAttributes::Role::AttrContainer> with the
 functionality of automatically initializing a metaclass for the caller and
 applying the meta roles relevant for capturing method attributes.
 
-
-
-=head1 AUTHORS
+=head1 AUTHOR
 
   Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
+the same terms as perl itself.
 
