@@ -1,5 +1,5 @@
 package MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped;
-our $VERSION = '0.16_01';
+our $VERSION = '0.02';
 
 # ABSTRACT: proxy attributes of wrapped methods if their metaclass supports it
 
@@ -11,11 +11,7 @@ use namespace::clean -except => 'meta';
 
 override wrap => sub {
     my $self = super;
-    my $original_method = $self->get_original_method;
-    if (
-        does_role($original_method, 'MooseX::MethodAttributes::Role::Meta::Method')
-        || does_role($original_method, 'MooseX::MethodAttributes::Role::Meta::Method::Wrapped')
-    ) {
+    if (does_role($self->get_original_method, 'MooseX::MethodAttributes::Role::Meta::Method')) {
         MooseX::MethodAttributes::Role::Meta::Method::Wrapped->meta->apply($self);
     }
     return $self;
@@ -24,29 +20,22 @@ override wrap => sub {
 1;
 
 __END__
-
-=pod
-
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped - proxy attributes of wrapped methods if their metaclass supports it
 
 =head1 VERSION
 
-version 0.16_01
+version 0.02
 
-=head1 AUTHORS
+=head1 AUTHOR
 
   Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
+the same terms as perl itself.
 
