@@ -1,5 +1,5 @@
 package MooseX::MethodAttributes::Role::Meta::Method::Wrapped;
-our $VERSION = '0.16_01';
+our $VERSION = '0.02';
 
 # ABSTRACT: wrapped metamethod role allowing code attribute introspection
 
@@ -13,24 +13,16 @@ sub attributes {
     return $self->get_original_method->attributes;
 }
 
-sub _get_attributed_coderef {
-    my ($self) = @_;
-    return $self->get_original_method->_get_attributed_coderef;
-}
-
 1;
 
 __END__
-
-=pod
-
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Method::Wrapped - wrapped metamethod role allowing code attribute introspection
 
 =head1 VERSION
 
-version 0.16_01
+version 0.02
 
 =head1 METHODS
 
@@ -38,20 +30,14 @@ version 0.16_01
 
 Gets the list of code attributes of the original method this meta method wraps.
 
-
-
-=head1 AUTHORS
+=head1 AUTHOR
 
   Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut 
-
+the same terms as perl itself.
 
